<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.ui" line="+14"/>
        <source>About Transmission</source>
        <translation>Acerca de Transmission</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Copyright © The Transmission Project</source>
        <translation>Copyright © The Transmission Project</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>A fast and easy BitTorrent client</source>
        <translation>Un cliente de BitTorrent rápido y fácil</translation>
    </message>
    <message>
        <location filename="../AboutDialog.cc" line="+37"/>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Server</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>C&amp;redits</source>
        <translation>C&amp;réditos</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;License</source>
        <translation>&amp;Licencia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Credits</source>
        <translation>Créditos</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../Application.cc" line="+332"/>
        <source>&lt;b&gt;Transmission is a file sharing program.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Transmission es un programa para compartir archivos.&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>When you run a torrent, its data will be made available to others by means of upload. Any content you share is your sole responsibility.</source>
        <translation>Cuando usas un torrent, sus datos estarán disponibles para otros por medio de la subida. Cualquier contenido que compartas es de tu responsabilidad.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>I &amp;Agree</source>
        <translation>&amp;Acepto</translation>
    </message>
    <message numerus="yes">
        <location line="+110"/>
        <source>Torrent(s) Completed</source>
        <translation>
            <numerusform>Torrents completado</numerusform>
            <numerusform>Torrents completados</numerusform>
        </translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Torrent Added</source>
        <translation>Torrent añadido</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../DetailsDialog.cc" line="+432"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mixed</source>
        <translation>Mezclado</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+267"/>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <location line="-210"/>
        <source>Finished</source>
        <translation>Terminado</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>Detenido</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>%1 (+%2 discarded after failed checksum)</source>
        <translation>%1$s (+ %2$s descartado después de fallar la comprobación de huella)</translation>
    </message>
    <message>
        <location line="+135"/>
        <source>Active now</source>
        <translation>Activo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 ago</source>
        <translation>hace %1</translation>
    </message>
    <message numerus="yes">
        <location line="+63"/>
        <source>%1 (%Ln pieces @ %2)</source>
        <translation>
            <numerusform>%1 (%n pieza @ %2)</numerusform>
            <numerusform>%1 (%Ln piezas @ %2)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%1 (%Ln pieces)</source>
        <translation>
            <numerusform>%1 (%n pieza)</numerusform>
            <numerusform>%1 (%Ln piezas)</numerusform>
        </translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Private to this tracker -- DHT and PEX disabled</source>
        <translation>Privado a este tracker -- DHT y PEX deshabilitado</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Public torrent</source>
        <translation>Torrent público</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Created by %1</source>
        <translation>Creado por %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created on %1</source>
        <translation>Creado el %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created by %1 on %2</source>
        <translation>Creado por %1 el %2</translation>
    </message>
    <message>
        <location line="+204"/>
        <location line="+47"/>
        <source>Encrypted connection</source>
        <translation>Conexión cifrada</translation>
    </message>
    <message>
        <location line="-28"/>
        <source>Optimistic unchoke</source>
        <translation>Desahogo optimista</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading from this peer</source>
        <translation>Descargando de este compañero</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would download from this peer if they would let us</source>
        <translation>Descargaríamos de este compañero si nos dejara</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Uploading to peer</source>
        <translation>Subiendo para este compañero</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would upload to this peer if they asked</source>
        <translation>Subiríamos para este compañero si nos lo pidiera</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer has unchoked us, but we&apos;re not interested</source>
        <translation>El compañero nos desahogo, pero no estamos interesados</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We unchoked this peer, but they&apos;re not interested</source>
        <translation>Nosotros desahogamos este compañero, pero él no está interesado</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer was discovered through DHT</source>
        <translation>Par encontrado a través de DHT</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer was discovered through Peer Exchange (PEX)</source>
        <translation>Compañero encontrado por Intercambio de pares (PEX)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is an incoming connection</source>
        <translation>El compañero es una conexión de entrada</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is connected over µTP</source>
        <translation>El par está conectado vía µTP</translation>
    </message>
    <message numerus="yes">
        <location line="+130"/>
        <source> minute(s)</source>
        <extracomment>Spin box suffix, &quot;Stop seeding if idle for: [ 5 minutes ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform> minuto</numerusform>
            <numerusform> minutos</numerusform>
        </translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Add tracker announce URLs, one per line:</source>
        <translation>Añadir URLs de anuncio del tracker, unot por linea:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No new URLs found.</source>
        <translation>No se han encontrado nuevas URLs.</translation>
    </message>
    <message>
        <location line="-843"/>
        <source>%1 (100%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data</extracomment>
        <translation>%1 (100%)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data, %2 is overall size of torrent data, %3 is percentage (%1/%2*100)</extracomment>
        <translation>%1 de %2 (%3%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%), %4 Unverified</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded data (both verified and unverified), %2 is overall size of torrent data, %3 is percentage (%1/%2*100), %4 is amount of downloaded but not yet verified data</extracomment>
        <translation>%1 de %2 (%3%), %4 Sin verificar</translation>
    </message>
    <message>
        <location line="+70"/>
        <source>%1 (Ratio: %2)</source>
        <translation>%1 (Proporción: %2)</translation>
    </message>
    <message>
        <location line="+273"/>
        <location line="+55"/>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <location line="+390"/>
        <source>Add URL(s)</source>
        <translation>Añadir URL(s)</translation>
    </message>
    <message>
        <location line="+114"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+4"/>
        <source>Use Global Settings</source>
        <translation>Usar Configuración Global</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Seed regardless of ratio</source>
        <translation>Compartir sin límite</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding at ratio:</source>
        <translation>Detener al llegar a:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Seed regardless of activity</source>
        <translation>Compartir sin importar la actividad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding if idle for:</source>
        <translation>Dejar de compartir si está inactivo:</translation>
    </message>
    <message>
        <location line="+75"/>
        <source>Up</source>
        <translation>Subiendo</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Down</source>
        <translation>Bajando</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <location filename="../DetailsDialog.ui" line="+14"/>
        <source>Torrent Properties</source>
        <translation>Propiedades del torrent</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Activity</source>
        <translation>Actividad</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Have:</source>
        <translation>Tenemos:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Availability:</source>
        <translation>Disponible:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Uploaded:</source>
        <translation>Subido:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Downloaded:</source>
        <translation>Descargado:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>State:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Running time:</source>
        <translation>Tiempo transcurrido:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Remaining time:</source>
        <translation>Tiempo restante:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Last activity:</source>
        <translation>Ultima actividad:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Error:</source>
        <translation>Mensaje de error:</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Location:</source>
        <translation>Localización:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Edit Trackers</source>
        <translation>Editar rastreadores</translation>
    </message>
    <message>
        <location line="-190"/>
        <source>Hash:</source>
        <translation>Hash:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Privacy:</source>
        <translation>Privacidad:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Origin:</source>
        <translation>Origen:</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Added:</source>
        <translation>Añadido:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Comment:</source>
        <translation>Comentario:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Peers</source>
        <translation>Pares</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add Tracker</source>
        <translation>Añadir rastreador</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Remove Trackers</source>
        <translation>Borrar rastreadores</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Show &amp;more details</source>
        <translation>Muestra &amp;más detalles</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show &amp;backup trackers</source>
        <translation>Muestrar rastreadores de &amp;respaldo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Files</source>
        <translation>Archivos</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Honor global &amp;limits</source>
        <translation>Respetar &amp;límites globales</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Limit &amp;download speed:</source>
        <translation>Limitar &amp;descarga:</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>Limit &amp;upload speed:</source>
        <translation>Limitar &amp;subida:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Torrent &amp;priority:</source>
        <translation>&amp;Prioridad del torrent:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Seeding Limits</source>
        <translation>Límite para compartir</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Ratio:</source>
        <translation>&amp;Proporción:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Idle:</source>
        <translation>&amp;Inactivo:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Peer Connections</source>
        <translation>Conexiones de pares</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Maximum peers:</source>
        <translation>&amp;Máximo de pares:</translation>
    </message>
</context>
<context>
    <name>FileTreeItem</name>
    <message>
        <location filename="../FileTreeItem.cc" line="+297"/>
        <location filename="../FileTreeView.cc" line="+108"/>
        <location line="+254"/>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-254"/>
        <location line="+252"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-252"/>
        <location line="+253"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-252"/>
        <source>Mixed</source>
        <translation>Mezclada</translation>
    </message>
</context>
<context>
    <name>FileTreeModel</name>
    <message>
        <location filename="../FileTreeModel.cc" line="+195"/>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Priority</source>
        <translation>Prioridad</translation>
    </message>
</context>
<context>
    <name>FileTreeView</name>
    <message>
        <location filename="../FileTreeView.cc" line="+244"/>
        <source>Check Selected</source>
        <translation>Marcar elegido</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uncheck Selected</source>
        <translation>Desmarcar elegido</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Only Check Selected</source>
        <translation>Sólo marcar lo elegido</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Priority</source>
        <translation>Prioridad</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rename…</source>
        <translation>Renombrar…</translation>
    </message>
</context>
<context>
    <name>FilterBar</name>
    <message>
        <location filename="../FilterBar.cc" line="+48"/>
        <location line="+145"/>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <location line="-136"/>
        <source>Active</source>
        <translation>Activos</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading</source>
        <translation>Descargando</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Seeding</source>
        <translation>Compartiendo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>Detenidos</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Finished</source>
        <translation>Terminados</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Verifying</source>
        <translation>Verificando</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location line="+140"/>
        <source>Show:</source>
        <translation>Mostrar:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Search…</source>
        <translation>Buscar…</translation>
    </message>
</context>
<context>
    <name>Formatter</name>
    <message>
        <location filename="../Formatter.cc" line="+24"/>
        <source>B/s</source>
        <translation>B/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>kB/s</source>
        <translation>kB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MB/s</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GB/s</source>
        <translation>GB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TB/s</source>
        <translation>TB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GB</source>
        <translation>GB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TB</source>
        <translation>TB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location line="+37"/>
        <location line="+25"/>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <location line="-20"/>
        <location line="+10"/>
        <source>None</source>
        <translation>Nada</translation>
    </message>
    <message>
        <location filename="../Formatter.h" line="+64"/>
        <location line="+7"/>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
    <message numerus="yes">
        <location filename="../Formatter.cc" line="+41"/>
        <source>%Ln day(s)</source>
        <translation>
            <numerusform>%n día</numerusform>
            <numerusform>%Ln días</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-5"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%n hora</numerusform>
            <numerusform>%Ln horas</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%n minuto</numerusform>
            <numerusform>%Ln minutos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln second(s)</source>
        <translation>
            <numerusform>%n segundo</numerusform>
            <numerusform>%Ln segundos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FreeSpaceLabel</name>
    <message>
        <location filename="../FreeSpaceLabel.cc" line="+52"/>
        <source>&lt;i&gt;Calculating Free Space…&lt;/i&gt;</source>
        <translation>&lt;i&gt;Calculando espacio libre…&lt;/i&gt;</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>%1 free</source>
        <translation>%1 Libre</translation>
    </message>
</context>
<context>
    <name>LicenseDialog</name>
    <message>
        <location filename="../LicenseDialog.ui" line="+14"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.ui" line="+14"/>
        <source>Transmission</source>
        <translation>Transmission</translation>
    </message>
    <message>
        <location line="+181"/>
        <source>&amp;Torrent</source>
        <translation>&amp;Torrent</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Create a new torrent</source>
        <translation>Crear un nuevo torrent</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Properties</source>
        <translation>&amp;Propiedades</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Show torrent properties</source>
        <translation>Mostrar propiedades del torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open the torrent&apos;s folder</source>
        <translation>Abrir el folder del torrent</translation>
    </message>
    <message>
        <location line="-161"/>
        <source>Queue</source>
        <translation>Cola</translation>
    </message>
    <message>
        <location line="-132"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location line="+83"/>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <location line="+171"/>
        <source>&amp;Open…</source>
        <translation>&amp;Abrir…</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open a torrent</source>
        <translation>Abrir el archivo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;New…</source>
        <translation>&amp;Nuevo…</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Open Fold&amp;er</source>
        <translation>Abrir la &amp;carpeta</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Start</source>
        <translation>&amp;Iniciar</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start torrent</source>
        <translation>Iniciar torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ask Tracker for &amp;More Peers</source>
        <translation>Pedir al rastreador &amp;más pares</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ask tracker for more peers</source>
        <translation>Pedir más pares al rastreador</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Pause torrent</source>
        <translation>Detener el torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Verify Local Data</source>
        <translation>&amp;Verificar datos locales</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Verify local data</source>
        <translation>Verificar los datos locales</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Remove</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent</source>
        <translation>Borrar el torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Delete Files and Remove</source>
        <translation>&amp;Eliminar archivos y borrar</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent and delete its files</source>
        <translation>Borrar el torrent y sus archivos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Start All</source>
        <translation>Iniciar &amp;todo</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause All</source>
        <translation>Dete&amp;ner todo</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Select All</source>
        <translation>&amp;Seleccionar todo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Deselect All</source>
        <translation>Seleccionar &amp;ninguno</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Preferencias</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Compact View</source>
        <translation>Vista &amp;compacta</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+3"/>
        <source>Compact View</source>
        <translation>Vista compacta</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Toolbar</source>
        <translation>&amp;Barra de herramientas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Filterbar</source>
        <translation>Barra de &amp;filtros</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statusbar</source>
        <translation>Barra de &amp;estados</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Activity</source>
        <translation>Ordenar por &amp;actividad</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by A&amp;ge</source>
        <translation>Ordenar por &amp;antigüedad</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Time &amp;Left</source>
        <translation>Ordenar por tiempo &amp;restante</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Name</source>
        <translation>Ordenar por &amp;nombre</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Progress</source>
        <translation>Ordenar por &amp;progreso</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Rati&amp;o</source>
        <translation>Ordenar por &amp;proporción</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Si&amp;ze</source>
        <translation>Ordenar por &amp;tamaño</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Stat&amp;e</source>
        <translation>Ordenar por &amp;estado</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by T&amp;racker</source>
        <translation>Ordenar por &amp;seguidor</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Message &amp;Log</source>
        <translation>Bitácora de &amp;mensajes</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statistics</source>
        <translation>&amp;Estadísticas</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Contents</source>
        <translation>&amp;Contenido</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Re&amp;verse Sort Order</source>
        <translation>&amp;Invertir orden</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Name</source>
        <translation>&amp;Nombre</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Files</source>
        <translation>&amp;Archivos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Tracker</source>
        <translation>&amp;Tracker</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Ratio</source>
        <translation>Proporción total</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Ratio</source>
        <translation>Proporción sesión</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Transfer</source>
        <translation>Transferencia total</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Transfer</source>
        <translation>Transferencia sesión</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Main Window</source>
        <translation>&amp;Ventana principal</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tray &amp;Icon</source>
        <translation>&amp;Icono en bandeja</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Change Session…</source>
        <translation>&amp;Cambiar sesión…</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Set &amp;Location…</source>
        <translation>Definir &amp;localización…</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Open &amp;URL…</source>
        <translation>Abrir &amp;URL…</translation>
    </message>
    <message>
        <location line="-15"/>
        <source>Choose Session</source>
        <extracomment>Start a local session or connect to a running session</extracomment>
        <translation>Seleccionar sesión</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Copy Magnet Link to Clipboard</source>
        <translation>&amp;Copiar enlace magnet al portapapeles</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Donate</source>
        <translation>&amp;Donar</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start &amp;Now</source>
        <translation>Iniciar &amp;ahora</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Bypass the queue and start now</source>
        <translation>Saltar la cola e iniciar ahora</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Move to &amp;Top</source>
        <translation>Mover al &amp;principio</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Move &amp;Up</source>
        <translation>Mover hacia &amp;arriba</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move &amp;Down</source>
        <translation>Mover hacia a&amp;bajo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move to &amp;Bottom</source>
        <translation>Mover al &amp;final</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Queue</source>
        <translation>Ordenar por &amp;cola</translation>
    </message>
    <message>
        <location filename="../MainWindow.cc" line="+468"/>
        <source>Limit Download Speed</source>
        <translation>Limitar velocidad de descarga</translation>
    </message>
    <message>
        <location line="-55"/>
        <source>Unlimited</source>
        <translation>Sin límite</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+752"/>
        <location line="+9"/>
        <source>Limited at %1</source>
        <translation>Limitada a %1</translation>
    </message>
    <message>
        <location line="-706"/>
        <source>Limit Upload Speed</source>
        <translation>Limitar velocidad de subida</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Stop Seeding at Ratio</source>
        <translation>Dejar de compartir al llegar la proporción</translation>
    </message>
    <message>
        <location line="-40"/>
        <source>Seed Forever</source>
        <translation>Compartir sin límite</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+739"/>
        <source>Stop at Ratio (%1)</source>
        <translation>Detener a la proporción (%1)</translation>
    </message>
    <message>
        <location line="-393"/>
        <source> - %1:%2</source>
        <extracomment>Second (optional) part of main window title &quot;Transmission - host:port&quot; (added when connected to remote session) notice that leading space (before the dash) is included here</extracomment>
        <translation> - %1:%2</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Idle</source>
        <translation>Sin cambio</translation>
    </message>
    <message>
        <location line="+30"/>
        <location line="+15"/>
        <source>Ratio: %1</source>
        <translation>Proporción: %1</translation>
    </message>
    <message>
        <location line="-10"/>
        <location line="+5"/>
        <source>Down: %1, Up: %2</source>
        <translation>Bajada: %1, Subida: %2</translation>
    </message>
    <message>
        <location line="+424"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Archivos torrent (*.torrent);;Todos los archivos (*.*)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show &amp;options dialog</source>
        <translation>Mostrar diálogo de &amp;opciones</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Open Torrent</source>
        <translation>Abrir torrent</translation>
    </message>
    <message>
        <location line="-1003"/>
        <source>Speed Limits</source>
        <translation>Límites de velocidad</translation>
    </message>
    <message>
        <location line="+537"/>
        <source>Network Error</source>
        <translation>Error de red</translation>
    </message>
    <message>
        <location line="+434"/>
        <source>Click to disable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>DeClick para desactivar temporalmente los limites de velocidad
(%1 Descarga, %2 Subida)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Click to enable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>Click para activar temporalmente los limites de velocidad
(%1 Descarga, %2 Subida)</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Remove torrent?</source>
        <translation>¿Borrar torrent?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Delete this torrent&apos;s downloaded files?</source>
        <translation>¿Borrar archivos descargados de este torrent?</translation>
    </message>
    <message numerus="yes">
        <location line="-4"/>
        <source>Remove %Ln torrent(s)?</source>
        <translation>
            <numerusform>¿Remover %Ln torrent?</numerusform>
            <numerusform>¿Borrar %Ln torrents?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-505"/>
        <source>Showing %L1 of %Ln torrent(s)</source>
        <translation>
            <numerusform>Mostrando %L1 de %Ln torrent</numerusform>
            <numerusform>Mostrando %L1 de %Ln torrents</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+510"/>
        <source>Delete these %Ln torrent(s)&apos; downloaded files?</source>
        <translation>
            <numerusform>¿Borrar archivos descargados de estos %Ln torrent?</numerusform>
            <numerusform>¿Borrar archivos descargados de estos %Ln torrents?</numerusform>
        </translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Once removed, continuing the transfer will require the torrent file or magnet link.</source>
        <translation>Una vez eliminado, para continuar la transferencia se requerirá el archivo .torrent o un enlace magnético.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Once removed, continuing the transfers will require the torrent files or magnet links.</source>
        <translation>Una vez removidos, continuar las transferencias va a requerir los archivos .torrent o las ligas magnéticas.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent has not finished downloading.</source>
        <translation>Este torrent no ha terminado de descargar.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>These torrents have not finished downloading.</source>
        <translation>Estos torrents no han terminado de descargar.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent is connected to peers.</source>
        <translation>Este torrent está conectado a pares.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>These torrents are connected to peers.</source>
        <translation>Estos torrent están conectados a pares.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>One of these torrents is connected to peers.</source>
        <translation>Uno de estos torrents está conectado a pares.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents are connected to peers.</source>
        <translation>Algunos de estos torrents están conectados a pares.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>One of these torrents has not finished downloading.</source>
        <translation>Uno de estos torrents no ha terminado de descargar.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents have not finished downloading.</source>
        <translation>Algunos de estos torrents no han terminado de descargar.</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>%1 has not responded yet</source>
        <translation>%1 no ha respondido</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 is responding</source>
        <translation>%1 está respondiendo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 last responded %2 ago</source>
        <translation>%1 respondió hace %2</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 is not responding</source>
        <translation>%1 no está respondiendo</translation>
    </message>
</context>
<context>
    <name>MakeDialog</name>
    <message>
        <location filename="../MakeDialog.ui" line="+17"/>
        <source>New Torrent</source>
        <translation>Nuevo torrent</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="+304"/>
        <source>&lt;i&gt;No source selected&lt;/i&gt;</source>
        <translation>&lt;i&gt;No se seleccionó la fuente&lt;/i&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="+5"/>
        <source>%Ln File(s)</source>
        <translation>
            <numerusform>%Ln archivo</numerusform>
            <numerusform>%Ln archivos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln Piece(s)</source>
        <translation>
            <numerusform>%Ln pieza</numerusform>
            <numerusform>%Ln piezas</numerusform>
        </translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 in %2; %3 @ %4</source>
        <translation>%1 en %2; %3 @ %4</translation>
    </message>
    <message>
        <location filename="../MakeDialog.ui" line="+9"/>
        <source>Files</source>
        <translation>Archivos</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Sa&amp;ve to:</source>
        <translation>&amp;Guardar en:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Source f&amp;older:</source>
        <translation>&amp;Carpeta fuente:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Source &amp;file:</source>
        <translation>&amp;Archivo fuente:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Piece s&amp;ize:</source>
        <translation>&amp;Tamaño de pieza: </translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Trackers:</source>
        <translation>&amp;Rastreadores</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>To add a backup URL, add it on the line after the primary URL.
To add another primary URL, add it after a blank line.</source>
        <translation>Para añadir una URL de respaldo, añádela en la línea posterior a la URL primaria.
Para añadir otra URL primaria, añádela después de una línea en blanco.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Co&amp;mment:</source>
        <translation>Co&amp;mentario:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Source:</source>
        <translation>&amp;Fuente:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Private torrent</source>
        <translation>Torrent &amp;privado</translation>
    </message>
</context>
<context>
    <name>MakeProgressDialog</name>
    <message>
        <location filename="../MakeProgressDialog.ui" line="+14"/>
        <source>New Torrent</source>
        <translation>Nuevo torrent</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="-184"/>
        <source>Creating &quot;%1&quot;</source>
        <translation>Creando «%1»</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Created &quot;%1&quot;!</source>
        <translation>¡«%1» creado!</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Couldn&apos;t create &quot;%1&quot;: %2 (%3)</source>
        <translation>No se pudo crear «%1»: %2 (%3)</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../OptionsDialog.cc" line="+52"/>
        <source>Open Torrent</source>
        <translation>Abrir torrent</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Open Torrent from File</source>
        <translation>Abrir torrent desde archivo</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open Torrent from URL or Magnet Link</source>
        <translation>Abrir URL del torrent o enlace magnet</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+17"/>
        <source>&amp;Source:</source>
        <translation>&amp;Fuente:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Destination folder:</source>
        <translation>Carpeta &amp;destino:</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="+49"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+35"/>
        <source>&amp;Priority:</source>
        <translation>&amp;Prioridad:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>S&amp;tart when added</source>
        <translation>&amp;Iniciar al añadir</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mo&amp;ve .torrent file to the trash</source>
        <translation>M&amp;over archivo .torrent a la papelera</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="-40"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Archivos torrent (*.torrent);;Todos los archivos (*.*)</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Select Destination</source>
        <translation>Seleccione destino</translation>
    </message>
</context>
<context>
    <name>PathButton</name>
    <message>
        <location filename="../PathButton.cc" line="+23"/>
        <location line="+71"/>
        <source>(None)</source>
        <translation>(Ninguno)</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Select Folder</source>
        <translation>Seleccione directorio</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Select File</source>
        <translation>Seleccione archivo</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <location filename="../PrefsDialog.ui" line="+1223"/>
        <source>Use &amp;authentication</source>
        <translation>Usar a&amp;utentificación</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Username:</source>
        <translation>&amp;Nombre de usuario:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>Cla&amp;ve de usuario:</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>&amp;Open web client</source>
        <translation>&amp;Abrir cliente de Web</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Addresses:</source>
        <translation>Direcciones:</translation>
    </message>
    <message>
        <location line="-1234"/>
        <source>Speed Limits</source>
        <translation>Límites de velocidad</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>&lt;small&gt;Override normal speed limits manually or at scheduled times&lt;/small&gt;</source>
        <translation>&lt;small&gt;Ignorar límites normales de velocidad manualmente o en horarios programados&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>&amp;Scheduled times:</source>
        <translation>&amp;Horarios programados:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>&amp;On days:</source>
        <translation>&amp;Días activos:</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+382"/>
        <source>Every Day</source>
        <translation>Todos los días</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekdays</source>
        <translation>Entre semana</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekends</source>
        <translation>Fin de semana</translation>
    </message>
    <message>
        <location line="-238"/>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <location line="+299"/>
        <source>Port is &lt;b&gt;open&lt;/b&gt;</source>
        <translation>El puerto está &lt;b&gt;abierto&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Port is &lt;b&gt;closed&lt;/b&gt;</source>
        <translation>El puerto está &lt;b&gt;cerrado&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Testing TCP Port…</source>
        <translation>Probando puerto TCP…</translation>
    </message>
    <message>
        <location line="+154"/>
        <source>Select &quot;Torrent Done Downloading&quot; Script</source>
        <translation>Seleccionar script para torrent completa la descarga</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="+545"/>
        <source>Incoming Peers</source>
        <translation>Conexiones de entrada</translation>
    </message>
    <message>
        <location line="+32"/>
        <location filename="../PrefsDialog.cc" line="+207"/>
        <source>Status unknown</source>
        <translation>Estado desconocido</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>&amp;Port for incoming connections:</source>
        <translation>&amp;Puerto para recibir conexiones:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Use UPnP or NAT-PMP port &amp;forwarding from my router</source>
        <translation>Usar UPnP o NAT-PMP para obtener un puerto y su mapeo de mi router</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="-255"/>
        <source> minute(s)</source>
        <extracomment>Spin box suffix, &quot;Stop seeding if idle for: [ 5 minutes ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform> minuto</numerusform>
            <numerusform> minutos</numerusform>
        </translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Select &quot;Torrent Done Seeding&quot; Script</source>
        <translation>Seleccionar script para torrent completa la siembra</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source> minute(s) ago</source>
        <extracomment>Spin box suffix, &quot;Download is inactive if data sharing stopped: [ 5 minutes ago ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform> minuto atrás</numerusform>
            <numerusform> minutos atrás</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-651"/>
        <source>Automatically add .torrent files &amp;from:</source>
        <translation>&amp;Añadir archivos .torrent desde:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Show the Torrent Options &amp;dialog</source>
        <translation>Mostrar el &amp;dialogo de opciones del Torrent</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>&amp;Start added torrents</source>
        <translation>I&amp;niciar torrents añadidos</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Mo&amp;ve the .torrent file to the trash</source>
        <translation>Mo&amp;ver el archivo .torrent a la papelera</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Download Queue</source>
        <translation>Cola de descargas</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Ma&amp;ximum active downloads:</source>
        <translation>Má&amp;ximo de descargas activas:</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Incomplete</source>
        <translation>Incompleto</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Seeding</source>
        <translation>Compartiendo</translation>
    </message>
    <message>
        <location line="+622"/>
        <source>Remote</source>
        <translation>Remoto</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="+168"/>
        <source>&lt;i&gt;Blocklist contains %Ln rule(s)&lt;/i&gt;</source>
        <translation>
            <numerusform>&lt;i&gt;Lista de bloqueos contiene %Ln regla&lt;/i&gt;</numerusform>
            <numerusform>&lt;i&gt;Lista de bloqueos contiene %Ln reglas&lt;/i&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-339"/>
        <source>Pick a &amp;random port every time Transmission is started</source>
        <translation>Seleccionar un puerto &amp;aleatorio al iniciar Transmission</translation>
    </message>
    <message>
        <location line="-274"/>
        <source>Limits</source>
        <translation>Límites</translation>
    </message>
    <message>
        <location line="+321"/>
        <source>Maximum peers per &amp;torrent:</source>
        <translation>Máximo número de pares por &amp;torrent:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Maximum peers &amp;overall:</source>
        <translation>Máximo número de pares &amp;global:</translation>
    </message>
    <message>
        <location line="-193"/>
        <source>Blocklist</source>
        <translation>Lista de bloqueo</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Enable &amp;automatic updates</source>
        <translation>Habilitar actualización &amp;automática</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="-227"/>
        <source>Allow encryption</source>
        <translation>Permitir cifrado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prefer encryption</source>
        <translation>Preferir cifrado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Require encryption</source>
        <translation>Requerir cifrado</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-97"/>
        <source>Privacy</source>
        <translation>Privacidad</translation>
    </message>
    <message>
        <location line="-435"/>
        <source>&amp;to</source>
        <translation>&amp;a</translation>
    </message>
    <message>
        <location line="+847"/>
        <location line="+9"/>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show Transmission icon in the &amp;notification area</source>
        <translation>Mostrar ícono de Transmission en el área de &amp;notificaciones</translation>
    </message>
    <message>
        <location line="-265"/>
        <source>Te&amp;st Port</source>
        <translation>P&amp;robar puerto</translation>
    </message>
    <message>
        <location line="-101"/>
        <source>Enable &amp;blocklist:</source>
        <translation>Habilitar lista de &amp;bloqueo:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Update</source>
        <translation>Act&amp;ualizar</translation>
    </message>
    <message>
        <location line="-66"/>
        <source>&amp;Encryption mode:</source>
        <translation>&amp;Modo de cifrado:</translation>
    </message>
    <message>
        <location line="+505"/>
        <source>Remote Control</source>
        <translation>Control remoto</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Allow &amp;remote access</source>
        <translation>Permitir control &amp;remoto</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>HTTP &amp;port:</source>
        <translation>&amp;Puerto HTTP:</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Only allow these IP a&amp;ddresses:</source>
        <translation>Solo permitir estas &amp;direcciones IP:</translation>
    </message>
    <message>
        <location line="-1212"/>
        <source>&amp;Upload:</source>
        <translation>&amp;Subida:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Download:</source>
        <translation>&amp;Descarga:</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Alternative Speed Limits</source>
        <translation>Limites de velocidad alternativos</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>U&amp;pload:</source>
        <translation>S&amp;ubida:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Do&amp;wnload:</source>
        <translation>D&amp;escarga:</translation>
    </message>
    <message>
        <location line="+186"/>
        <source>Reads user clipboard content for torrents</source>
        <translation>Lee torrents del contenido del portapapeles</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Detect new torrents from clipboard</source>
        <translation>Detectar nuevos torrents del portapapeles</translation>
    </message>
    <message>
        <location line="+148"/>
        <source>Call scrip&amp;t when downloading is completed:</source>
        <translation>Ejecutar scrip&amp;t al completar la descarga:</translation>
    </message>
    <message>
        <location line="+105"/>
        <source>Call scrip&amp;t when seeding is completed:</source>
        <translation>Ejecutar scrip&amp;t al completar la siembra:</translation>
    </message>
    <message>
        <location line="+342"/>
        <source>µTP is a tool for reducing network congestion.</source>
        <translation>µTP es una herramienta para reducir la congestión de la red.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Enable µ&amp;TP for peer connections</source>
        <translation>Habilitar µ&amp;TP en conexiones con pares</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Default Public Trackers</source>
        <translation>Rastreadores públicos por defecto</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trackers to use on all public torrents.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;p&gt;To add a backup URL, add it on the next line after a primary URL.&lt;/p&gt;&lt;p&gt;To add a new primary URL, add it after a blank line.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Rastreadores a usar en todos los torrents públicos.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;p&gt;Para añadir una copia de seguridad de URL, añádala en la siguiente línea después de la URL primaria.&lt;/p&gt;&lt;p&gt;To add a new primary URL, add it after a blank line.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Start &amp;minimized in notification area</source>
        <translation>Empezar &amp;minimizado en el área de notificaciones</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Notification</source>
        <translation>Notificación</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show a notification when torrents are a&amp;dded</source>
        <translation>Mostrar notificación cuando los torrents son aña&amp;didos</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show a notification when torrents &amp;finish</source>
        <translation>Mostrar notificación cuando los torrents &amp;finalizan</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Play a &amp;sound when torrents finish</source>
        <translation>Reproducir un &amp;sonido cuando los torrents terminan</translation>
    </message>
    <message>
        <location line="-281"/>
        <source>Peer Limits</source>
        <translation>Limite de pares</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Use PE&amp;X to find more peers</source>
        <translation>Usar PE&amp;X para encontrar más pares</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>PEX is a tool for exchanging peer lists with the peers you&apos;re connected to.</source>
        <translation>PEX es una herramienta para intercambiar listas de pares con los que ya están conectados.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;DHT to find more peers</source>
        <translation>Usar &amp;DHT para encontrar más pares</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>DHT is a tool for finding peers without a tracker.</source>
        <translation>DHT es una herramienta para encontrar pares sin usar un rastreador.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;Local Peer Discovery to find more peers</source>
        <translation>Usar descubrimiento de pares &amp;local para encontrar más pares</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>LPD is a tool for finding peers on your local network.</source>
        <translation>LPD es una herramienta para encontrar pares en la red local.</translation>
    </message>
    <message>
        <location line="-325"/>
        <source>Encryption</source>
        <translation>Cifrado</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+75"/>
        <source>Select Incomplete Directory</source>
        <translation>Seleccionar directorio para incompletos</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Select Watch Directory</source>
        <translation>Seleccionar directorio de guardia</translation>
    </message>
    <message numerus="yes">
        <location line="-101"/>
        <source>&lt;b&gt;Update succeeded!&lt;/b&gt;&lt;p&gt;Blocklist now has %Ln rule(s).&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;b&gt;¡Actualización exitosa!&lt;/b&gt;&lt;p&gt;La lista de bloqueos ahora tiene %Ln regla.&lt;/p&gt;</numerusform>
            <numerusform>&lt;b&gt;¡Actualización exitosa!&lt;/b&gt;&lt;p&gt;La lista de bloqueos ahora tiene %Ln reglas.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;b&gt;Update Blocklist&lt;/b&gt;&lt;p&gt;Getting new blocklist…&lt;/p&gt;</source>
        <translation>&lt;b&gt;Actualizar lista de bloqueos&lt;/b&gt;&lt;p&gt;Obteniendo nueva lista…&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Select Destination</source>
        <translation>Seleccionar destino</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-387"/>
        <source>Adding</source>
        <translation>Al añadir</translation>
    </message>
    <message>
        <location line="+147"/>
        <source>Download is i&amp;nactive if data sharing stopped:</source>
        <extracomment>Please keep this phrase as short as possible, it&apos;s currently the longest and influences dialog width</extracomment>
        <translation>La &amp;Descarga esta inactiva si se compartió por ultima vez:</translation>
    </message>
    <message>
        <location line="-156"/>
        <source>Downloading</source>
        <translation>Descargando</translation>
    </message>
    <message>
        <location line="+215"/>
        <source>Append &quot;.&amp;part&quot; to incomplete files&apos; names</source>
        <translation>Añadir .&amp;part al nombre de archivos incompletos</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Keep &amp;incomplete files in:</source>
        <translation>Mantener archivos &amp;incompletos en:</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Save to &amp;Location:</source>
        <translation>&amp;Guardar en:</translation>
    </message>
    <message>
        <location line="+282"/>
        <source>Stop seeding at &amp;ratio:</source>
        <translation>Dejar de compartir llegando a &amp;proporción:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Stop seedi&amp;ng if idle for:</source>
        <translation>Dejar de compartir si está i&amp;nactivo:</translation>
    </message>
    <message>
        <location line="-567"/>
        <source>Transmission Preferences</source>
        <translation>Preferencias del programa</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
    <message>
        <location line="+735"/>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+116"/>
        <source>Not supported by remote sessions</source>
        <translation>No soportado por sesiones remotas</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../Application.cc" line="-313"/>
        <source>Invalid option</source>
        <translation>Opción inválida</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Start Now</source>
        <translation>Empezar ahora</translation>
    </message>
</context>
<context>
    <name>RelocateDialog</name>
    <message>
        <location filename="../RelocateDialog.cc" line="+65"/>
        <source>Select Location</source>
        <translation>Seleccione localización</translation>
    </message>
    <message>
        <location filename="../RelocateDialog.ui" line="+14"/>
        <source>Set Torrent Location</source>
        <translation>Defina localización del torrent</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Set Location</source>
        <translation>Definir localización</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>New &amp;location:</source>
        <translation>Nueva &amp;localización:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Move from the current folder</source>
        <translation>&amp;Mover del directorio actual</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Local data is &amp;already there</source>
        <translation>Los datos locales &amp;ya están ahí</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../Session.cc" line="+505"/>
        <source>Error Renaming Path</source>
        <translation>Error renombrando la ruta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;p&gt;&lt;b&gt;Unable to rename &quot;%1&quot; as &quot;%2&quot;: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please correct the errors and try again.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;No se puede renombrar &quot;%1&quot; como &quot;%2&quot;: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Por favor corrija los errores e inténtelo de nuevo.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+528"/>
        <source>Error Adding Torrent</source>
        <translation>Error al añadir torrent</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>%1 (copy of %2)</source>
        <translation>%1 (copia de %2)</translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source>Duplicate Torrent(s)</source>
        <translation>
            <numerusform>Torrent duplicado</numerusform>
            <numerusform>Torrents duplicados</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+2"/>
        <source>Unable to add %n duplicate torrent(s)</source>
        <translation>
            <numerusform>No se puede añadir %n torrent duplicado</numerusform>
            <numerusform>No se pueden añadir %n torrents duplicados</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <location filename="../SessionDialog.ui" line="+14"/>
        <source>Change Session</source>
        <translation>Cambiar sesión</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Start &amp;Local Session</source>
        <translation>Empezar sesión &amp;local</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Connect to &amp;Remote Session</source>
        <translation>Conectar a sesión &amp;remota</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Host:</source>
        <translation>&amp;Anfitrión:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Port:</source>
        <translation>&amp;Puerto:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Authentication required</source>
        <translation>&amp;Autentificación requerida</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Username:</source>
        <translation>&amp;Nombre de usuario</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>&amp;Clave de usuario:</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <location filename="../StatsDialog.ui" line="+14"/>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Current Session</source>
        <translation>Sesión actual</translation>
    </message>
    <message>
        <location line="+12"/>
        <location line="+96"/>
        <source>Uploaded:</source>
        <translation>Subido:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Downloaded:</source>
        <translation>Descargados:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Ratio:</source>
        <translation>Proporción:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Duration:</source>
        <translation>Duración:</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message numerus="yes">
        <location filename="../StatsDialog.cc" line="+63"/>
        <source>Started %Ln time(s)</source>
        <translation>
            <numerusform>Iniciado %n vez</numerusform>
            <numerusform>Iniciado %Ln veces</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Torrent</name>
    <message>
        <location filename="../Torrent.cc" line="+323"/>
        <source>Verifying local data</source>
        <translation>Verificando datos locales</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Downloading</source>
        <translation>Descargando</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Seeding</source>
        <translation>Compartiendo</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Finished</source>
        <translation>Terminado</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paused</source>
        <translation>Detenido</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Queued for verification</source>
        <translation>En cola para verificación</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for download</source>
        <translation>En cola para descarga</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for seeding</source>
        <translation>En cola para compartir</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Tracker gave a warning: %1</source>
        <translation>El tracker dio una advertencia: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tracker gave an error: %1</source>
        <translation>El tracker dio un error: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
</context>
<context>
    <name>TorrentDelegate</name>
    <message>
        <location filename="../TorrentDelegate.cc" line="+174"/>
        <source>Magnetized transfer - retrieving metadata (%1%)</source>
        <extracomment>First part of torrent progress string, %1 is the percentage of torrent metadata downloaded</extracomment>
        <translation>Transferencia magnética - descargando metadata (%1%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is how much we&apos;ll have when done, %3 is a percentage of the two</extracomment>
        <translation>%1 de %2 (%3%)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5 Goal: %6)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio, %6 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1 de %2 (%3%), subido %4 (Proporción: %5 Meta: %6)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio</extracomment>
        <translation>%1 de %2 (%3%), subido %4 (Proporción: %5)</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>%1, uploaded %2 (Ratio: %3 Goal: %4)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio, %4 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1, subido %2 (Proporción: %3 Meta: %4)</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>%1, uploaded %2 (Ratio: %3)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio</extracomment>
        <translation>%1, subido %2 (Proporción: %3)</translation>
    </message>
    <message>
        <location line="+15"/>
        <source> - %1 left</source>
        <extracomment>Second (optional) part of torrent progress string, %1 is duration, notice that leading space (before the dash) is included here</extracomment>
        <translation> - falta %1</translation>
    </message>
    <message>
        <location line="+6"/>
        <source> - Remaining time unknown</source>
        <extracomment>Second (optional) part of torrent progress string, notice that leading space (before the dash) is included here</extracomment>
        <translation> - Tiempo faltante desconocido</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Ratio: %1</source>
        <translation>Proporción: %1</translation>
    </message>
    <message numerus="yes">
        <location line="+44"/>
        <source>Downloading from %Ln peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Descargando desde %Ln par</numerusform>
            <numerusform>Descargando desde %Ln pares</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+22"/>
        <source>Seeding to %Ln peer(s)</source>
        <translation>
            <numerusform>Compartiendo a %Ln par</numerusform>
            <numerusform>Compartiendo a %Ln pares</numerusform>
        </translation>
    </message>
    <message>
        <location line="+18"/>
        <source> - </source>
        <translation> - </translation>
    </message>
    <message numerus="yes">
        <location line="-50"/>
        <source>Downloading metadata from %Ln peer(s) (%1% done)</source>
        <translation>
            <numerusform>Descargando metadata desde %Ln par (%1% obtenido)</numerusform>
            <numerusform>Descargando metadatos desde %Ln pares (%1% obtenido)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+15"/>
        <source>Downloading from %1 of %Ln connected peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Descargando desde %1 de %Ln par conectado</numerusform>
            <numerusform>Descargando desde %1 de %Ln pares conectados</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+8"/>
        <source> and %Ln web seed(s)</source>
        <extracomment>Second (optional) part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;, notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform> y %Ln web seed</numerusform>
            <numerusform> y %Ln web seeds</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+13"/>
        <source>Seeding to %1 of %Ln connected peer(s)</source>
        <translation>
            <numerusform>Compartiendo a %1 de %Ln par conectado</numerusform>
            <numerusform>Compartiendo a %1 de %Ln pares conectados</numerusform>
        </translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Verifying local data (%1% tested)</source>
        <translation>Verificando datos locales (%1% probado)</translation>
    </message>
</context>
<context>
    <name>TrackerDelegate</name>
    <message numerus="yes">
        <location filename="../TrackerDelegate.cc" line="+216"/>
        <source>Got a list of%1 %Ln peer(s)%2 %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>
            <numerusform>Recibimos una lista de%1 %Ln par%2 hace %3</numerusform>
            <numerusform>Recibimos una lista de%1 %Ln pares%2 hace %3</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer list request %1timed out%2 %3 ago; will retry</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>El pedido de la lista de pares %1caducó hace %2 %3; se volverá a intentar</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Got an error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>Obtuvimos un error %1&quot;%2&quot;%3 hace %4</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>No updates scheduled</source>
        <translation>No hay actualizaciones programadas</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Asking for more peers in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Solicitando más pares en %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for more peers</source>
        <translation>En cola para pedir más pares</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Asking for peer counts now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Solicitando recuento de pares ahora… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="-40"/>
        <source>Tracker had%1 %Ln seeder(s)%2</source>
        <extracomment>First part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup</extracomment>
        <translation>
            <numerusform>El seguidor tenía%1 %Ln compartiendo%2</numerusform>
            <numerusform>El seguidor tenía%1 %Ln compartiendos%2</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source> and%1 %Ln leecher(s)%2 %3 ago</source>
        <extracomment>Second part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup, %3 is duration; notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform> y%1 %Ln descargando%2 hace %3</numerusform>
            <numerusform> y%1 %Ln descargandos%2 hace %3</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tracker had %1no information%2 on peer counts %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>El rastredor tenía %1nada%2 del recuento de pares hace %3</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>Got a scrape error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>Obtuvimos un error de barrido&apos; %1&quot;%2&quot;%3 hace %4</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Asking for more peers now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Solicitando más pares ahora… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Asking for peer counts in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Solicitando recuento de pares en %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for peer counts</source>
        <translation>En cola para pedir recuento de pares</translation>
    </message>
</context>
<context>
    <name>TrackersDialog</name>
    <message>
        <location filename="../TrackersDialog.ui" line="+17"/>
        <source>Edit Trackers</source>
        <translation>Editar rastreadores</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Tracker Announce URLs</source>
        <translation>URLs de anuncio de rastreadores</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>To add a new primary URL, add it after a blank line.</source>
        <translation>Para añadir una nueva URL primaria, añádala después de una linea en blanco</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To add a backup URL, add it on the next line after a primary URL.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Para añadir una URL de copia de seguridad, añádala en la siguiente linea después de la URL primaria.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Also see Default Public Trackers in Edit &gt; Preferences &gt; Network</source>
        <translation>Ver también Rastreadores públicos por defecto en Editar &gt; Preferencias &gt; Red</translation>
    </message>
</context>
</TS>
